@@ -1,6 +1,7 @@
 import logging
 import os
 import sys
+from StringIO import StringIO
 
 from sprinter import virtualenv
 from sprinter import brew
@@ -9,7 +10,7 @@ from sprinter.directory import Directory
 from sprinter.exceptions import SprinterException
 from sprinter.injections import Injections
 from sprinter.lib import get_formula_class
-from sprinter.manifest import Config, Manifest
+from sprinter.manifest import Config, Manifest, ManifestException
 from sprinter.system import System
 
 
@@ -40,8 +41,15 @@ def populate_formula_instance(config):
 
         def wrapped(self, feature_name, formula_instance=None):
             if not formula_instance:
-                formula_instance = self._get_formula_instance(
-                    getattr(self, config).get_feature_class(feature_name))
+                try:
+                    formula_instance = self._get_formula_instance(
+                        getattr(self, config).get_feature_class(feature_name))
+                except ManifestException:
+                    self.logger.warn("Unable to retrieve formula for feature %s!" % feature_name)
+                except ImportError:
+                    self.logger.warn("Unable to retrieve formula for feature %s!" % feature_name)
+            if not formula_instance:
+                return None
             return f(self, feature_name, formula_instance=formula_instance)
         return wrapped
     return wrapper
@@ -64,13 +72,16 @@ class Environment(object):
     _formula_dict = {}  # a dictionary of existing formula instances to pull from
     sprinter_namespace = None  # the namespace to make installs with. this affects:
     # the prefix added to injections
-    last_phase = None # the last phase run
+    last_phase = None  # the last phase run
+    # a list of errors that occured within the environment's run.
+    # an error should be a tuple with the source of the error and the description.
+    errors = []
 
-    def __init__(self, logger=None, logging_level=logging.INFO, root=None, sprinter_namespace='sprinter'):
+    def __init__(self, logger=None, logging_level=logging.INFO,
+                 root=None, sprinter_namespace='sprinter'):
         self.system = System()
         if not logger:
             logger = self._build_logger(level=logging.INFO)
-        logger.setLevel(logging_level)
         self.logger = logger
         self.sprinter_namespace = sprinter_namespace
         self.root = root or os.path.expanduser(os.path.join("~", ".%s" % sprinter_namespace))
@@ -88,6 +99,7 @@ class Environment(object):
         try:
             self.logger.info("Installing environment %s..." % self.namespace)
             self.directory.initialize()
+            self.install_sandboxes()
             self._specialize_contexts()
             for feature in self.config.installs():
                 self.install_feature(feature)
@@ -102,10 +114,13 @@ class Environment(object):
         
     @warmup
     @install_required
-    def update(self):
+    def update(self, reconfigure=False):
         """ update the environment """
         self.last_phase = "update"
         self.logger.info("Updating environment %s..." % self.namespace)
+        self.install_sandboxes()
+        if reconfigure:
+            self.config.grab_inputs(force_prompt=True)
         self._specialize_contexts()
         for feature in self.config.installs():
             self.install_feature(feature)
@@ -113,6 +128,7 @@ class Environment(object):
             self.update_feature(feature)
         for feature in self.config.removes():
             self.remove_feature(feature)
+        self.inject_environment_rc()
         self._finalize()
 
     @warmup
@@ -154,6 +170,16 @@ class Environment(object):
         self.inject_environment_rc()
         self._finalize()
 
+    @warmup
+    @install_required
+    def reconfigure(self):
+        """ reconfigure the environment """
+        self.last_phase = "reconfigure"
+        self.config.grab_inputs(force_prompt=True)
+        if os.path.exists(self.directory.manifest_path):
+            self.config.write(open(self.directory.manifest_path, "w+"))
+        self.logger.info("Reconfigured! Note: It's recommended to update after a configure")
+
     @warmup
     @populate_formula_instance('target')
     def install_feature(self, feature_name, formula_instance=None):
@@ -200,8 +226,9 @@ class Environment(object):
 
     @warmup
     def inject_environment_rc(self):
-        self.injections.inject("~/.profile", "[ -d %s ] && . %s/.rc" %
-                               (self.directory.root_dir, self.directory.root_dir))
+        # clearing profile for now, to make sure
+        # profile injections are cleared for sprinter installs
+        self.injections.clear("~/.profile")
         self.injections.inject("~/.bash_profile", "[ -d %s ] && . %s/.rc" %
                                (self.directory.root_dir, self.directory.root_dir))
         self.injections.inject("~/.bashrc", "[ -d %s ] && . %s/.rc" %
@@ -213,6 +240,32 @@ class Environment(object):
         self.injections.clear("~/.bash_profile")
         self.injections.clear("~/.bashrc")
 
+    def install_sandboxes(self):
+        # install virtualenv
+        if self.target:
+            self._install_sandbox('virtualenv', virtualenv.create_environment,
+                                  {'use_distribute': True})
+            if self.system.isOSX():
+                self._install_sandbox('brew', brew.install_brew)
+
+    def write_debug_log(self, file_path):
+        """ Write the debug log to a file """
+        with open(file_path, "w+") as fh:
+            fh.write(self._debug_stream.getvalue())
+
+    def message_failure(self):
+        """ return a failure message, if one exists """
+        manifest = self.target or self.source
+        if manifest.has_option('config', 'message_failure'):
+            return manifest.get('config', 'message_failure')
+        return None
+
+    def message_success(self):
+        """ return a success message, if one exists """
+        manifest = self.target or self.source
+        if manifest.has_option('config', 'message_success'):
+            return manifest.get('config', 'message_success')
+
     def _warmup(self):
         """ initialize variables necessary to perform a sprinter action """
         self.logger.debug("Warming up...")
@@ -231,12 +284,6 @@ class Environment(object):
         if not self.directory:
             self.directory = Directory(self.namespace, sprinter_root=self.root)
         self.injections = Injections(wrapper="%s_%s" % (self.sprinter_namespace.upper(), self.namespace))
-        # install virtualenv
-        if self.target:
-            self._install_sandbox('virtualenv', virtualenv.create_environment,
-                                  {'use_distribute': True})
-            if self.system.isOSX():
-                self._install_sandbox('brew', brew.install_brew)
         # append the bin, in the case sandboxes are necessary to
         # execute commands further down the sprinter lifecycle
         os.environ['PATH'] = self.directory.bin_path() + ":" + os.environ['PATH']
@@ -244,7 +291,7 @@ class Environment(object):
 
     def _finalize(self):
         """ command to run at the end of sprinter's run """
-        self.logger.debug("Finalizing...")
+        self.logger.info("Finalizing...")
         if os.path.exists(self.directory.manifest_path):
             self.config.write(open(self.directory.manifest_path, "w+"))
         if self.directory.rewrite_rc:
@@ -252,6 +299,8 @@ class Environment(object):
             self.directory.add_to_rc("export LIBRARY_PATH=%s:$LIBRARY_PATH" % self.directory.lib_path())
             self.directory.add_to_rc("export C_INCLUDE_PATH=%s:$C_INCLUDE_PATH" % self.directory.include_path())
         self.injections.commit()
+        if self.message_success():
+            self.logger.info(self.message_success())
 
     def _install_sandbox(self, name, call, kwargs={}):
         if (self.target.is_true('config', name) and
@@ -261,11 +310,18 @@ class Environment(object):
 
     def _build_logger(self, level=logging.INFO):
         """ return a logger. if logger is none, generate a logger from stdout """
+        self._debug_stream = StringIO()
         logger = logging.getLogger('sprinter')
+        # stdout log
         out_hdlr = logging.StreamHandler(sys.stdout)
-        out_hdlr.setFormatter(logging.Formatter('%(asctime)s %(message)s'))
         out_hdlr.setLevel(level)
         logger.addHandler(out_hdlr)
+        # debug log
+        debug_hdlr = logging.StreamHandler(self._debug_stream)
+        debug_hdlr.setFormatter(logging.Formatter('%(asctime)s %(message)s'))
+        debug_hdlr.setLevel(logging.DEBUG)
+        logger.addHandler(debug_hdlr)
+        logger.setLevel(logging.DEBUG)
         return logger
 
     def _get_formula_instance(self, formula):
@@ -273,15 +329,19 @@ class Environment(object):
         get an instance of the formula object object if it exists, else
         create one, add it to the dict, and pass return it.
         """
-        #if formula not in self._formula_dict:
-        #self._formula_dict[formula] = get_formula_class(formula, self)
-        #return self._formula_dict[formula]
         return get_formula_class(formula, self)
 
-    def _run_action(self, adjective, feature_name, call, configs):
-        self.logger.info("%s %s..." % (adjective, feature_name))
+    def _run_action(self, verb, feature_name, call, configs):
+        self.logger.info("%s %s..." % (verb, feature_name))
         configs = [getattr(self.config, c).get_feature_config(feature_name) for c in configs]
-        call(feature_name, *configs)
+        valid = True
+        for c in configs:
+            if 'formula' not in c:
+                valid = False
+        if valid:
+            call(feature_name, *configs)
+        else:
+            self.logger.warn("Feature %s has invalid configs! Not %s" % (feature_name, verb))
 
     def _specialize_contexts(self):
         """ Add variables and specialize contexts """
