@@ -24,7 +24,6 @@ class TestEnvFormula(FormulaTest):
         """ The egg formula should install a single egg """
         self.environment.directory.add_to_rc = Mock()
         self.environment.install_feature("simple_example")
-        self.environment.directory.add_to_rc.assert_has_call("export USER=toumorokoshi")
-        self.environment.directory.add_to_rc.assert_has_call("export MAVEN_HOME=~/bin/mvn")
-        self.environment.directory.add_to_rc.assert_has_call("export user=toumorokoshi")
-        self.environment.directory.add_to_rc.assert_has_call("export user=toumorokoshi")
+        self.environment.directory.add_to_rc.assert_any_call("export USER=toumorokoshi")
+        self.environment.directory.add_to_rc.assert_any_call("export MAVEN_HOME=~/bin/mvn")
+        self.environment.directory.add_to_rc.assert_any_call("export M2_PATH=~/.m2/")
