@@ -12,9 +12,10 @@ strip-top-level-directory=True
 """
 
 import os
-import shutil
 
 from sprinter.formulabase import FormulaBase
+from sprinter.exceptions import ExtractException
+from sprinter.directory import DirectoryException
 
 
 class UnpackFormula(FormulaBase):
@@ -31,11 +32,14 @@ class UnpackFormula(FormulaBase):
         if (source_config['formula'] != target_config['formula']
            or source_config['url'] != target_config['url']):
             if os.path.exists(self.directory.install_directory(feature_name)):
-                shutil.rmtree(self.directory.install_directory(feature_name))
+                try:
+                    self.directory.remove_feature(feature_name)
+                except DirectoryException:
+                    self.logger.error("Unable to remove old directory!")
             self.__install(feature_name, target_config)
             if 'command' in target_config:
                 self.logger.info(self.lib.call(target_config['command'],
-                                               bash=True,
+                                               shell=True,
                                                cwd=self.directory.install_directory(feature_name)))
         if 'executable' in source_config:
             symlink = source_config['symlink'] if 'symlink' in source_config else source_config['executable']
@@ -43,7 +47,7 @@ class UnpackFormula(FormulaBase):
                 try:
                     self.directory.remove_from_bin(source_config['symlink'] if 'symlink' in source_config
                                                    else source_config['executable'])
-                except OSError:
+                except DirectoryException:
                     pass
         if 'executable' in target_config:
             symlink_target = target_config['symlink'] if 'symlink' in target_config else target_config['executable']
@@ -60,18 +64,21 @@ class UnpackFormula(FormulaBase):
                                config['remove_common_prefix'].lower().startswith('t')
         destination = (self.directory.install_directory(feature_name) if 'target'
                        not in config else config['target'])
-        if config['type'] == "tar.gz":
-            self.lib.extract_targz(config['url'], destination,
-                                   remove_common_prefix=remove_common_prefix)
-        elif config['type'] == "zip":
-            self.lib.extract_zip(config['url'], destination,
-                                 remove_common_prefix=remove_common_prefix)
-        elif config['type'] == "dmg":
-            if not self.system.isOSX():
-                self.logger.warn("Non OSX based distributions can not install a dmg!")
-            else:
-                self.lib.extract_dmg(config['url'], destination,
+        try:
+            if config['type'] == "tar.gz":
+                self.lib.extract_targz(config['url'], destination,
+                                       remove_common_prefix=remove_common_prefix)
+            elif config['type'] == "zip":
+                self.lib.extract_zip(config['url'], destination,
                                      remove_common_prefix=remove_common_prefix)
+            elif config['type'] == "dmg":
+                if not self.system.isOSX():
+                    self.logger.warn("Non OSX based distributions can not install a dmg!")
+                else:
+                    self.lib.extract_dmg(config['url'], destination,
+                                         remove_common_prefix=remove_common_prefix)
+        except ExtractException:
+            self.logger.warn("Unable to extract file for feature %s" % feature_name)
 
     def __symlink_executable(self, feature_name, source, target):
         source_path = os.path.join(self.directory.install_directory(feature_name), source)
