@@ -21,7 +21,7 @@ Install an environment as specified in a sprinter config file
 """
 
 VALID_COMMANDS = ["install", "update", "remove", "deactivate", "activate",
-                  "environments", "validate"]
+                  "environments", "reconfigure", "validate"]
 
 parser = OptionParser(description=description)
 # parser = argparse.ArgumentParser(description=description)
@@ -37,6 +37,8 @@ parser.add_option('--auth', dest='auth', action='store_true',
 parser.add_option('--password', dest='password', default=None,
                   help="Password if the url requires authentication")
 parser.add_option('-v', dest='verbose', action='store_true', help="Make output verbose")
+parser.add_option('--reconfigure', dest='reconfigure', default=False,
+                  help="if true, a sprinter update will reconfigure the existing environment specified")
 # not implemented yet
 parser.add_option('--sandboxbrew', dest='sandbox_brew', default=False,
                   help="if true, sandbox a brew installation, alternatively, " +
@@ -82,51 +84,64 @@ def parse_args(argv, Environment=Environment):
     logging_level = logging.DEBUG if options.verbose else logging.INFO
     # start processing commands
     env = Environment(logging_level=logging_level)
+    try:
+        if command == "install":
+            def handle_install_shutdown(signal, frame):
+                if env.last_phase == "install":
+                    print "Removing install..."
+                    env.directory.remove()
+                    env.clear_environment_rc()
+                signal_handler(signal, frame)
+            signal.signal(signal.SIGINT, handle_install_shutdown)
+            if options.username or options.auth:
+                options = get_credentials(options, parse_domain(target))
+                target = Manifest(target, username=options.username, password=options.password)
+            env.target = target
+            env.namespace = options.namespace
+            env.install()
 
-    if command == "install":
-        def handle_install_shutdown(signal, frame):
-            if env.last_phase == "install":
-                print "Removing install..."
-                env.directory.remove()
-                env.clear_environment_rc()
-            signal_handler(signal, frame)
-        signal.signal(signal.SIGINT, handle_install_shutdown)
-        if options.username or options.auth:
-            options = get_credentials(options, parse_domain(target))
-            target = Manifest(target, username=options.username, password=options.password)
-        env.target = target
-        env.namespace = options.namespace
-        env.install()
+        elif command == "update":
+            env.directory = Directory(target)
+            env.source = Manifest(env.directory.manifest_path)
+            if options.username or options.auth:
+                options = get_credentials(options, target)
+            env.target = Manifest(env.source.source(),
+                                  username=options.username,
+                                  password=options.password)
+            env.update(reconfigure=options.reconfigure)
 
-    elif command == "update":
-        env.directory = Directory(target)
-        env.source = Manifest(env.directory.manifest_path)
-        if options.username or options.auth:
-            options = get_credentials(options, target)
-        env.target = Manifest(env.source.source(),
-                              username=options.username,
-                              password=options.password)
-        env.update()
+        elif command in ["remove", "deactivate", "activate", "reconfigure"]:
+            env.directory = Directory(target)
+            env.source = Manifest(env.directory.manifest_path, namespace=target)
+            getattr(env, command)()
 
-    elif command in ["remove", "deactivate", "activate"]:
-        env.directory = Directory(target)
-        env.source = Manifest(env.directory.manifest_path)
-        getattr(env, command)()
+        elif command == "environments":
+            SPRINTER_ROOT = os.path.expanduser(os.path.join("~", ".sprinter"))
+            for env in os.listdir(SPRINTER_ROOT):
+                print "%s" % env
 
-    elif command == "environments":
-        SPRINTER_ROOT = os.path.expanduser(os.path.join("~", ".sprinter"))
-        for env in os.listdir(SPRINTER_ROOT):
-            print "%s" % env
-
-    elif command == "validate":
-        if options.username or options.auth:
-            options = get_credentials(parse_domain(target))
-        errors = env.validate_manifest(target, username=options.username, password=options.password)
-        if len(errors) > 0:
-            print "Manifest is invalid!"
-            print "\n".join(errors)
+        elif command == "validate":
+            if options.username or options.auth:
+                options = get_credentials(parse_domain(target))
+            errors = env.validate_manifest(target, username=options.username, password=options.password)
+            if len(errors) > 0:
+                print "Manifest is invalid!"
+                print "\n".join(errors)
+            else:
+                print "Manifest is valid!"
+    except BadCredentialsException, e:
+        raise e
+    except Exception, e:
+        if not isinstance(e, SprinterException):
+            env.logger.exception("An exception occurred!")
         else:
-            print "Manifest is valid!"
+            env.logger.error(str(e))
+        env.logger.info("failed! Writing debug output to /tmp/sprinter.log")
+        env.write_debug_log("/tmp/sprinter.log")
+        if env.message_failure():
+            env.logger.info(env.message_failure)
+        if not isinstance(e, SprinterException):
+            raise e
 
 
 def parse_domain(url):
