@@ -79,8 +79,9 @@ class Manifest(object):
             self.get(section, option).lower().startswith('t')
 
     def get_feature_class(self, section):
-        if section not in self.formula_sections():
-            raise ManifestException("Cannot get feature %s!" % section)
+        if (section not in self.formula_sections() or
+           not self.manifest.has_option(section, 'formula')):
+            raise ManifestException("Cannot get formula %s!" % section)
         return self.manifest.get(section, 'formula')
 
     def get_feature_config(self, feature):
@@ -220,7 +221,6 @@ class Config(object):
     # a list of values to not save into the config.
     # e.g. passwords
     temporary_sections = []
-    source_location = None
     config = {}
 
     def __init__(self, source=None, target=None, namespace=None, lib=lib):
@@ -231,10 +231,6 @@ class Config(object):
         self.lib = lib
         self.source = source
         self.target = target
-        if self.target:
-            self.source_location = self.target.source()
-        if self.source and not self.source_location:
-            self.source.source()
         # store raws to use on write
         self.source_raw = source
         self.target_raw = target
@@ -288,7 +284,7 @@ class Config(object):
         return [s for s in self.source.formula_sections()
                 if self.source.run_phase(s, "activate")]
 
-    def grab_inputs(self, manifest=None):
+    def grab_inputs(self, manifest=None, force_prompt=False):
         """
         Look for any inputs not already accounted for in the manifest, and
         query the user for them.
@@ -306,7 +302,7 @@ class Config(object):
                         else:
                             default = (attributes['default'] if 'default' in attributes else None)
                             secret = (attributes['secret'] if 'secret' in attributes else False)
-                            self.get_config(param, default=default, secret=secret)
+                            self.get_config(param, default=default, secret=secret, force_prompt=force_prompt)
             if self.target:
                 self.set_additional_context('target')
             if self.source:
@@ -324,15 +320,13 @@ class Config(object):
             if k not in self.temporary_sections:
                 self.target.set('config', k, v)
         self.target.set('config', 'namespace', self.namespace)
-        if self.source_location:
-            self.target.set('config', 'source', self.source_location)
         self.target.write(file_handle)
 
-    def get_config(self, param_name, default=None, secret=False):
+    def get_config(self, param_name, default=None, secret=False, force_prompt=False):
         """
         grabs a config from the user space; if it doesn't exist, it will prompt for it.
         """
-        if param_name not in self.config:
+        if param_name not in self.config or force_prompt:
             self.config[param_name] = self.lib.prompt("please enter your %s" % param_name,
                                                       default=default,
                                                       secret=secret)
